#-----------------------------
# -- kongodb --
#-----------------------------

from . import adapters, dict_query, lib, database, exceptions

# alias to Database
kongodb = database.Database


